@@ -15,7 +15,7 @@ import requests
 from kerasltisubmission import exceptions
 from kerasltisubmission.kerasltisubmission import Submission
 from kerasltisubmission.provider import InputsType, LTIProvider, PredictionsType
-from tests.mocks import JSONType, MockKerasModel, MockRequestsResponse
+from tests.mocks import JSONType, MockRequestsResponse, mocked_keras_model
 
 
 @pytest.fixture  # type: ignore
@@ -32,7 +32,7 @@ def provider() -> LTIProvider:
 def submission() -> Submission:
     """Sample submission"""
     # model = tf.keras.models.load_model(str((Path(__file__).parent / 'mnist.h5').absolute()))
-    model = MockKerasModel(predicts=np.array([0, 2, 4, 6]))
+    model = mocked_keras_model(predicts=np.array([0, 2, 4, 6]))
     return Submission(assignment_id=12, model=model)
 
 
@@ -907,6 +907,23 @@ def assignment_input(
             yield mocked_get, mocked_post
 
 
+def test_safe_shape(provider: LTIProvider) -> None:
+    assert provider.safe_shape((None, 28, 28, 1)) == (-1, 28, 28, 1)
+    assert provider.safe_shape((None, None, 28, 1)) == (-1, -1, 28, 1)
+    assert provider.safe_shape((None, 28, 28, None)) == (-1, 28, 28, -1)
+    assert provider.safe_shape((None,)) == (-1,)
+    assert provider.safe_shape((2, 1)) == (2, 1)
+    assert provider.safe_shape(()) == ()
+
+    test = np.zeros(shape=(200, 28, 28))
+    assert test.reshape(provider.safe_shape((None, 28, 28, 1))).shape == (
+        200,
+        28,
+        28,
+        1,
+    )
+
+
 def test_input_request(
     provider: LTIProvider, submission: Submission, prediction_input: PredictionsType
 ) -> None:
@@ -914,7 +931,7 @@ def test_input_request(
     for v in verbosity:
         with assignment_input(
             json_data=dict(success=True, predict=prediction_input),
-            post_json_response=dict(success=True),
+            post_json_response=dict(success=True, grade=0.5, accuracy=0.5),
         ) as (_, mocked_post):
             provider.submit(submission, verbose=v)
             posted = mocked_post.call_args_list
@@ -958,7 +975,7 @@ def test_exception_metadata(
     try:
         with assignment_input(
             json_data=dict(success=True, predict=prediction_input),
-            post_json_response=dict(success=False),
+            post_json_response=dict(success=False, grade=0.5, accuracy=0.5),
         ) as (_, _):
             submission.submit(provider)
     except exceptions.KerasLTISubmissionBadResponseException as e:
@@ -968,7 +985,7 @@ def test_exception_metadata(
     try:
         with assignment_input(
             json_data=dict(success=True, predict=prediction_input),
-            post_json_response=dict(success=False),
+            post_json_response=dict(success=False, grade=0.5, accuracy=0.5),
         ) as (_, mocked_post):
 
             def simulate_connection_error(
